@@ -125,9 +125,11 @@ na.interp <- function(x, lambda=NULL,
 #' @param x time series
 #' @param replace.missing If TRUE, it not only replaces outliers, but also
 #' interpolates missing values
+#' @param iterate the number of iterations required
 #' @inheritParams forecast
 #' @return Time series
 #' @author Rob J Hyndman
+#' @references Hyndman (2021) "Detecting time series outliers" \url{https://robjhyndman.com/hyndsight/tsoutliers/}.
 #' @seealso \code{\link[forecast]{na.interp}},
 #' \code{\link[forecast]{tsoutliers}}, \code{\link[stats]{supsmu}}
 #' @keywords ts
@@ -136,8 +138,8 @@ na.interp <- function(x, lambda=NULL,
 #' cleangold <- tsclean(gold)
 #'
 #' @export
-tsclean <- function(x, replace.missing=TRUE, lambda = NULL) {
-  outliers <- tsoutliers(x, lambda = lambda)
+tsclean <- function(x, replace.missing=TRUE, iterate=2, lambda = NULL) {
+  outliers <- tsoutliers(x, iterate = iterate, lambda = lambda)
   x[outliers$index] <- outliers$replacements
   if (replace.missing) {
     x <- na.interp(x, lambda = lambda)
@@ -155,12 +157,13 @@ tsclean <- function(x, replace.missing=TRUE, lambda = NULL) {
 #'
 #'
 #' @param x time series
-#' @param iterate the number of iteration only for non-seasonal series
+#' @param iterate the number of iterations required
 #' @inheritParams forecast
 #' @return \item{index}{Indicating the index of outlier(s)}
 #' \item{replacement}{Suggested numeric values to replace identified outliers}
 #' @author Rob J Hyndman
 #' @seealso \code{\link[forecast]{na.interp}}, \code{\link[forecast]{tsclean}}
+#' @references Hyndman (2021) "Detecting time series outliers" \url{https://robjhyndman.com/hyndsight/tsoutliers/}.
 #' @keywords ts
 #' @examples
 #'
@@ -237,7 +240,11 @@ tsoutliers <- function(x, iterate=2, lambda=NULL) {
     {
       outliers <- sort(unique(c(outliers, tmp$index)))
       x[outliers] <- NA
-      x <- na.interp(x, lambda = lambda)
+      if(sum(!is.na(x)) == 1L) {
+        # Only one non-missing value
+        x[is.na(x)] <- x[!is.na(x)]
+      } else
+        x <- na.interp(x, lambda = lambda)
     }
   }
 
