@@ -449,7 +449,7 @@ ets <- function(y, model="ZZZ", damped=NULL,
   model$sigma2 <- sum(model$residuals^2, na.rm = TRUE) / (ny - np)
   model$x <- orig.y
   if (!is.null(lambda)) {
-    model$fitted <- InvBoxCox(model$fitted, lambda, biasadj, var(model$residuals))
+    model$fitted <- InvBoxCox(model$fitted, lambda, biasadj, model$sigma2)
     attr(lambda, "biasadj") <- biasadj
   }
 
@@ -1104,7 +1104,9 @@ lik <- function(par, y, nstate, errortype, trendtype, seasontype, damped, par.no
 #' @export
 print.ets <- function(x, ...) {
   cat(paste(x$method, "\n\n"))
-  cat(paste("Call:\n", deparse(x$call), "\n\n"))
+  if(!is.null(x$call)) {
+    cat(paste("Call:\n", deparse(x$call), "\n\n"))
+  }
   ncoef <- length(x$initstate)
   if (!is.null(x$lambda)) {
     cat("  Box-Cox transformation: lambda=", round(x$lambda, 4), "\n\n")
@@ -1323,9 +1325,15 @@ plot.ets <- function(x, ...) {
 
 #' @export
 summary.ets <- function(object, ...) {
-  print(object)
+  class(object) <- c("summary.ets", class(object))
+  object
+}
+
+#' @export
+print.summary.ets <- function(x, ...) {
+  NextMethod()
   cat("\nTraining set error measures:\n")
-  print(accuracy(object))
+  print(accuracy(x))
 }
 
 #' @export
