@@ -241,17 +241,23 @@ print.forecast <- function(x, ...) {
 
 #' @export
 summary.forecast <- function(object, ...) {
-  cat(paste("\nForecast method:", object$method))
-  #    cat(paste("\n\nCall:\n",deparse(object$call)))
+  class(object) <- c("summary.forecast", class(object))
+  object
+}
+
+#' @export
+print.summary.forecast <- function(x, ...) {
+  cat(paste("\nForecast method:", x$method))
+  #    cat(paste("\n\nCall:\n",deparse(x$call)))
   cat(paste("\n\nModel Information:\n"))
-  print(object$model)
+  print(x$model)
   cat("\nError measures:\n")
-  print(accuracy(object))
-  if (is.null(object$mean)) {
+  print(accuracy(x))
+  if (is.null(x$mean)) {
     cat("\n No forecasts\n")
   } else {
     cat("\nForecasts:\n")
-    print(object)
+    NextMethod()
   }
 }
 
@@ -560,7 +566,7 @@ hfitted <- function(object, h=1, FUN=NULL, ...) {
   n <- length(fits)
   refitarg <- list(x = NULL, model = object)
   names(refitarg)[1] <- names(formals(FUN))[1]
-  fcarg <- list(h = h)
+  fcarg <- list(h = h, biasadj=TRUE, lambda=object$lambda)
   if (FUN == "ets") {
     refitarg$use.initial.values <- TRUE
   }
@@ -573,6 +579,9 @@ hfitted <- function(object, h=1, FUN=NULL, ...) {
     }
     fcarg$object <- try(suppressWarnings(do.call(FUN, refitarg)), silent = TRUE)
     if (!is.element("try-error", class(fcarg$object))) {
+      # Keep original variance estimate (for consistent bias adjustment)
+      if(!is.null(object$sigma2))
+        fcarg$object$sigma2 <- object$sigma2
       fits[i + h] <- suppressWarnings(do.call("forecast", fcarg)$mean[h])
     }
   }
@@ -676,11 +685,14 @@ as.data.frame.forecast <- function(x, ...) {
   colnames(out) <- names
   tx <- time(x$mean)
   if (max(abs(tx - round(tx))) < 1e-11) {
-    nd <- 0
+    nd <- 0L
   } else {
-    nd <- max(round(log10(fr.x) + 1), 2)
+    nd <- max(round(log10(fr.x) + 1), 2L)
   }
-  rownames(out) <- format(tx, nsmall = nd, digits = nd)
+  if(nd == 0L)
+    rownames(out) <- round(tx)
+  else
+    rownames(out) <- format(tx, nsmall = nd, digits = nd)
   # Rest of function borrowed from print.ts(), but with header() omitted
   if (!ists) {
     return(as.data.frame(out))
