@@ -19,7 +19,7 @@
 #' @param npaths Number of bootstrapped sample paths to use if \code{bootstrap==TRUE}.
 #' @param x Deprecated. Included for backwards compatibility.
 #' @inheritParams forecast
-#' 
+#'
 #' @return An object of class "\code{forecast}".
 #'
 #' The function \code{summary} is used to obtain and print a summary of the
@@ -94,13 +94,11 @@ meanf <- function(y, h=10, level=c(80, 95), fan=FALSE, lambda=NULL, biasadj=FALS
   }
   colnames(lower) <- colnames(upper) <- paste(level, "%", sep = "")
   if (is.ts(x)) {
-    fits <- ts(fits)
-    res <- ts(res)
-    tsp(fits) <- tsp(res) <- tsp(x)
-    freq <- frequency(x)
-    f <- ts(f, start = tsp(x)[2] + 1 / freq, frequency = freq)
-    lower <- ts(lower, start = tsp(x)[2] + 1 / freq, frequency = freq)
-    upper <- ts(upper, start = tsp(x)[2] + 1 / freq, frequency = freq)
+    fits <- copy_msts(x, fits)
+    res <- copy_msts(x, res)
+    f <- future_msts(x, f)
+    lower <- future_msts(x, lower)
+    upper <- future_msts(x, upper)
   }
 
   if (!is.null(lambda)) {
@@ -121,21 +119,19 @@ meanf <- function(y, h=10, level=c(80, 95), fan=FALSE, lambda=NULL, biasadj=FALS
 }
 
 
-
-
 #' Box Cox Transformation
 #'
 #' BoxCox() returns a transformation of the input variable using a Box-Cox
 #' transformation. InvBoxCox() reverses the transformation.
 #'
-#' The Box-Cox transformation is given by \deqn{f_\lambda(x) =\frac{x^\lambda -
-#' 1}{\lambda}}{f(x;lambda)=(x^lambda - 1)/lambda} if \eqn{\lambda\ne0}{lambda
+#' The Box-Cox transformation (as given by Bickel & Doksum 1981) is given by \deqn{f_\lambda(x) =sign(x)(|x|^\lambda -
+#' 1)/\lambda}{f(x;lambda)=sign(x)(|x|^lambda - 1)/lambda} if \eqn{\lambda\ne0}{lambda
 #' is not equal to 0}. For \eqn{\lambda=0}{lambda=0},
 #' \deqn{f_0(x)=\log(x)}{f(x;0)=log(x)}.
 #'
 #' @param x a numeric vector or time series of class \code{ts}.
-#' @param lambda transformation parameter. If \code{lambda = "auto"}, then 
-#' the transformation parameter lambda is chosen using BoxCox.lambda.
+#' @param lambda transformation parameter. If \code{lambda = "auto"}, then
+#' the transformation parameter lambda is chosen using BoxCox.lambda (with a lower bound of -0.9)
 #' @param biasadj Use adjusted back-transformed mean for Box-Cox
 #' transformations. If transformed data is used to produce forecasts and fitted values,
 #' a regular back transformation will result in median forecasts. If biasadj is TRUE,
@@ -148,6 +144,7 @@ meanf <- function(y, h=10, level=c(80, 95), fan=FALSE, lambda=NULL, biasadj=FALS
 #' @seealso \code{\link{BoxCox.lambda}}
 #' @references Box, G. E. P. and Cox, D. R. (1964) An analysis of
 #' transformations. \emph{JRSS B} \bold{26} 211--246.
+#' Bickel, P. J. and Doksum K. A. (1981) An Analysis of Transformations Revisited. \emph{JASA} \bold{76} 296-311.
 #' @keywords ts
 #' @examples
 #'
@@ -158,7 +155,7 @@ meanf <- function(y, h=10, level=c(80, 95), fan=FALSE, lambda=NULL, biasadj=FALS
 #' @export
 BoxCox <- function(x, lambda) {
   if (lambda == "auto") {
-    lambda <- BoxCox.lambda(x)
+    lambda <- BoxCox.lambda(x, lower = -0.9)
   }
   if (lambda < 0) {
     x[x < 0] <- NA
@@ -219,7 +216,7 @@ InvBoxCox <- function(x, lambda, biasadj=FALSE, fvar=NULL) {
     if (NCOL(fvar) > 1) {
       fvar <- diag(fvar)
     }
-    out <- out * (1 + 0.5 * fvar * (1 - lambda) / (out) ^ (2 * lambda))
+    out <- out * (1 + 0.5 * as.numeric(fvar) * (1 - lambda) / (out) ^ (2 * lambda))
   }
   return(out)
 }
@@ -272,7 +269,7 @@ InvBoxCoxf <- function(x=NULL, fvar=NULL, lambda=NULL) {
 #' fan plots.
 #' @param ... Other arguments.
 #' @inheritParams forecast
-#' 
+#'
 #' @return An object of class "\code{forecast}".
 #'
 #' The function \code{summary} is used to obtain and print a summary of the
@@ -330,8 +327,11 @@ forecast.StructTS <- function(object, h=ifelse(object$coef["epsilon"] > 1e-10, 2
     method <- "Local level structural model"
   }
 
-  fits <- ts(c(x - residuals(object)))
-  tsp(fits) <- tsp(x)
+  # Compute fitted values and residuals
+  sigma2 <- c(predict(object, n.ahead=1)$se)
+  res <- residuals(object) * sigma2
+  fits <- x - res
+
   if (!is.null(lambda)) {
     fits <- InvBoxCox(fits, lambda)
     x <- InvBoxCox(x, lambda)
@@ -340,11 +340,16 @@ forecast.StructTS <- function(object, h=ifelse(object$coef["epsilon"] > 1e-10, 2
     upper <- InvBoxCox(upper, lambda)
   }
 
+  mean <- future_msts(x, pred$pred)
+  lower <- future_msts(x, lower)
+  upper <- future_msts(x, upper)
+  fits <- copy_msts(x, fits)
+  res <- copy_msts(x, res)
 
   return(structure(
     list(
       method = method, model = object, level = level, mean = pred$pred,
-      lower = lower, upper = upper, x = x, series = object$series, fitted = fits, residuals = x-fits
+      lower = lower, upper = upper, x = x, series = object$series, fitted = fits, residuals = res
     ),
     class = "forecast"
   ))
@@ -369,7 +374,7 @@ forecast.StructTS <- function(object, h=ifelse(object$coef["epsilon"] > 1e-10, 2
 #' fan plots.
 #' @param ... Other arguments.
 #' @inheritParams forecast
-#' 
+#'
 #' @return An object of class "\code{forecast}".
 #'
 #' The function \code{summary} is used to obtain and print a summary of the
@@ -447,7 +452,11 @@ forecast.HoltWinters <- function(object, h=ifelse(frequency(object$x) > 1, 2 * f
   nf <- length(fitted)
   n <- length(x)
   fitted <- ts(c(rep(NA, n - nf), fitted))
-  tsp(fitted) <- tsp(object$x)
+  fitted <- copy_msts(object$x, fitted)
+
+  pmean <- future_msts(object$x, pmean)
+  lower <- future_msts(object$x, lower)
+  upper <- future_msts(object$x, upper)
 
   return(structure(
     list(
@@ -462,8 +471,6 @@ forecast.HoltWinters <- function(object, h=ifelse(frequency(object$x) > 1, 2 * f
 
 ## CROSTON
 
-
-
 #' Forecasts for intermittent demand using Croston's method
 #'
 #' Returns forecasts and other information for Croston's forecasts applied to
@@ -567,8 +574,8 @@ croston2 <- function(x, h=10, alpha=0.1, nofits=FALSE) {
       for (i in 1:(n - 1))
         fits[i + 1] <- croston2(x[1:i], h = 1, alpha = alpha, nofits = TRUE)
     }
-    fits <- ts(fits)
-    tsp(fits) <- tsp.x
+    ratio <- future_msts(x, ratio)
+    fits <- copy_msts(x, fits)
     return(list(mean = ratio, fitted = fits, model = list(demand = y.f, period = p.f)))
   }
 }
