@@ -114,7 +114,7 @@ autoplot.acf <- function(object, ci=0.95, ...) {
     data <- as.data.frame.table(acf)[-1]
     data$lag <- as.numeric(lag)
 
-    if (object$type == "correlation") {
+    if (object$type == "correlation" & is.null(object$ccf)) {
       data <- data[data$lag != 0, ]
     }
 
@@ -191,14 +191,10 @@ autoplot.acf <- function(object, ci=0.95, ...) {
 ggAcf <- function(x, lag.max = NULL,
                   type = c("correlation", "covariance", "partial"),
                   plot = TRUE, na.action = na.contiguous, demean=TRUE, ...) {
-  cl <- match.call()
-  if (plot) {
-    cl$plot <- FALSE
-  }
-  cl[[1]] <- quote(Acf)
-  object <- eval.parent(cl)
+  object <- Acf(x, lag.max = lag.max, type = type, na.action = na.action, demean = demean, plot = FALSE)
   object$tsp <- tsp(x)
   object$periods <- attributes(x)$msts
+  object$series <- deparse(substitute(x))
   if (plot) {
     return(autoplot(object, ...))
   }
@@ -212,6 +208,8 @@ ggAcf <- function(x, lag.max = NULL,
 ggPacf <- function(x, lag.max = NULL,
                    plot = TRUE, na.action = na.contiguous, demean=TRUE, ...) {
   object <- Acf(x, lag.max = lag.max, type = "partial", na.action = na.action, demean = demean, plot = FALSE)
+  object$tsp <- tsp(x)
+  object$periods <- attributes(x)$msts
   object$series <- deparse(substitute(x))
   if (plot) {
     return(autoplot(object, ...))
@@ -224,12 +222,7 @@ ggPacf <- function(x, lag.max = NULL,
 #' @export
 ggCcf <- function(x, y, lag.max=NULL, type=c("correlation", "covariance"),
                   plot=TRUE, na.action=na.contiguous, ...) {
-  cl <- match.call()
-  if (plot) {
-    cl$plot <- FALSE
-  }
-  cl[[1]] <- quote(Ccf)
-  object <- eval.parent(cl)
+  object <- Ccf(x, y, lag.max = lag.max, type = type, na.action = na.action, plot = FALSE)
   object$snames <- paste(deparse(substitute(x)), "&", deparse(substitute(y)))
   object$ccf <- TRUE
   if (plot) {
@@ -1248,7 +1241,14 @@ ggsubseriesplot <- function(x, labels = NULL, times = time(x), phase = cycle(x),
 
     # Create x-axis labels
     xfreq <- frequency(x)
-    if (xfreq == 4) {
+    if (!is.null(labels)) {
+      if (xfreq != length(labels)) {
+        stop("The number of labels supplied is not the same as the number of seasons.")
+      } else {
+        xbreaks <- labels
+      }
+    }
+    else if (xfreq == 4) {
       xbreaks <- c("Q1", "Q2", "Q3", "Q4")
       xlab <- "Quarter"
     }
@@ -1371,7 +1371,7 @@ ggseasonplot <- function(x, season.labels=NULL, year.labels=FALSE, year.labels.l
   if (year.labels || year.labels.left) {
     yrlab <- merge(yrlab, data)
     yrlab$time <- yrlab$time + yrlab$offset
-    p <- p + ggplot2::guides(colour = FALSE)
+    p <- p + ggplot2::guides(colour = "none")
     p <- p + ggplot2::geom_text(ggplot2::aes_(x = ~time, y = ~y, label = ~year), data = yrlab)
   }
 
@@ -1473,7 +1473,7 @@ autoplot.stl <- function(object, labels = NULL, range.bars = TRUE, ...) {
     p <- ggplot2::ggplot(ggplot2::aes_(x = ~datetime, y = ~y), data = data)
 
     # Add data
-    # Timeseries lines
+    # Time series lines
     p <- p + ggplot2::geom_line(ggplot2::aes_(x = ~datetime, y = ~y), data = subset(data, data$parts != cn[4]), na.rm = TRUE)
     p <- p + ggplot2::geom_segment(
       ggplot2::aes_(x = ~datetime, xend = ~datetime, y = 0, yend = ~y),
@@ -1592,12 +1592,15 @@ autoplot.StructTS <- function(object, labels = NULL, range.bars = TRUE, ...) {
 #' @examples
 #'
 #' library(ggplot2)
-#' co2 %>% decompose %>% autoplot
-#' nottem %>% stl(s.window='periodic') %>% autoplot
-#'
+#' co2 %>%
+#'   decompose() %>%
+#'   autoplot()
+#' nottem %>%
+#'   stl(s.window = "periodic") %>%
+#'   autoplot()
 #' \dontrun{
 #' library(seasonal)
-#' seas(USAccDeaths) %>% autoplot
+#' seas(USAccDeaths) %>% autoplot()
 #' }
 #'
 #' @export
@@ -1605,71 +1608,79 @@ autoplot.seas <- function(object, labels = NULL, range.bars = NULL, ...) {
   if (!requireNamespace("ggplot2", quietly = TRUE)) {
     stop("ggplot2 is needed for this function to work. Install it via install.packages(\"ggplot2\")", call. = FALSE)
   }
-  else {
-    if (!inherits(object, "seas")) {
-      stop("autoplot.seas requires a seas object")
-    }
-    if (is.null(labels)) {
-      labels <- c("trend", "seasonal", "remainder")
-    }
-
-    data <- cbind(object$x, object$data[, c("trend", "seasonal", "irregular")])
-    cn <- c("data", labels)
-    data <- data.frame(
-      datetime = rep(time(data), NCOL(data)), y = c(data),
-      parts = factor(rep(cn, each = NROW(data)), levels = cn)
-    )
-
-    # Is it additive or multiplicative?
-    freq <- frequency(seasonal(object))
-    sum_first_year <- sum(seasonal(object)[seq(freq)])
-    int <- as.integer(sum_first_year > 0.5) # Closer to 1 than 0.
-
-    # Initialise ggplot object
-    p <- ggplot2::ggplot(ggplot2::aes_(x = ~datetime, y = ~y), data = data)
-
-    # Add data
-    p <- p + ggplot2::geom_line(ggplot2::aes_(x = ~datetime, y = ~y), data = subset(data, data$parts != cn[4]), na.rm = TRUE)
-    p <- p + ggplot2::geom_segment(
-      ggplot2::aes_(x = ~datetime, xend = ~datetime, y = int, yend = ~y),
-      data = subset(data, data$parts == cn[4]), lineend = "butt"
-    )
-    p <- p + ggplot2::facet_grid("parts ~ .", scales = "free_y", switch = "y")
-    p <- p + ggplot2::geom_hline(ggplot2::aes_(yintercept = ~y),
-                                 data = data.frame(y = int, parts = factor(cn[4], levels = cn)))
-
-    # Rangebars
-    if (is.null(range.bars)) {
-      range.bars <- object$spc$transform$`function` == "none"
-    }
-    if (range.bars) {
-      yranges <- vapply(split(data$y, data$parts), function(x) range(x, na.rm = TRUE), numeric(2))
-      xranges <- range(data$datetime)
-      barmid <- apply(yranges, 2, mean)
-      barlength <- min(apply(yranges, 2, diff))
-      barwidth <- (1 / 64) * diff(xranges)
-      barpos <- data.frame(
-        left = xranges[2] + barwidth, right = xranges[2] + barwidth * 2,
-        top = barmid + barlength / 2, bottom = barmid - barlength / 2,
-        parts = factor(colnames(yranges), levels = cn),
-        datetime = xranges[2], y = barmid
-      )
-      p <- p + ggplot2::geom_rect(ggplot2::aes_(xmin = ~left, xmax = ~right, ymax = ~top, ymin = ~bottom), data = barpos, fill = "gray75", colour = "black", size = 1 / 3)
-    }
-
-    # Add axis labels
-    p <- p + ggAddExtras(xlab = "Time", ylab = "")
-
-    # Make x axis contain only whole numbers (e.g., years)
-    p <- p + ggplot2::scale_x_continuous(breaks = unique(round(pretty(data$datetime))))
-
-    return(p)
+  if (!inherits(object, "seas")) {
+    stop("autoplot.seas requires a seas object")
   }
+  if (is.null(labels)) {
+    if ("seasonal" %in% colnames(object$data)) {
+      labels <- c("trend", "seasonal", "irregular")
+    } else {
+      labels <- c("trend", "irregular")
+    }
+  }
+  data <- cbind(object$x, object$data[, labels])
+  colnames(data) <- cn <- c("data", labels)
+
+  data <- data.frame(
+    datetime = rep(time(data), NCOL(data)), y = c(data),
+    parts = factor(rep(cn, each = NROW(data)), levels = cn)
+  )
+
+  # Is it additive or multiplicative?
+  freq <- frequency(object$data)
+  sum_first_year <- try(sum(seasonal(object)[seq(freq)]), silent=TRUE)
+  if(!inherits(sum_first_year, "try-error")) {
+    int <- as.integer(sum_first_year > 0.5) # Closer to 1 than 0.
+  } else {
+    int <- 0
+  }
+
+  # Initialise ggplot object
+  p <- ggplot2::ggplot(ggplot2::aes_(x = ~datetime, y = ~y), data = data)
+  # Add data
+  p <- p + ggplot2::geom_line(ggplot2::aes_(x = ~datetime, y = ~y),
+                              data = subset(data, data$parts != tail(cn,1)),
+                              na.rm = TRUE)
+  p <- p + ggplot2::geom_segment(
+    ggplot2::aes_(x = ~datetime, xend = ~datetime, y = int, yend = ~y),
+    data = subset(data, data$parts == tail(cn,1)), lineend = "butt"
+  )
+  p <- p + ggplot2::facet_grid("parts ~ .", scales = "free_y", switch = "y")
+  p <- p + ggplot2::geom_hline(ggplot2::aes_(yintercept = ~y),
+    data = data.frame(y = int, parts = factor(tail(cn,1), levels = cn))
+  )
+
+  # Rangebars
+  if (is.null(range.bars)) {
+    range.bars <- object$spc$transform$`function` == "none"
+  }
+  if (range.bars) {
+    yranges <- vapply(split(data$y, data$parts), function(x) range(x, na.rm = TRUE), numeric(2))
+    xranges <- range(data$datetime)
+    barmid <- apply(yranges, 2, mean)
+    barlength <- min(apply(yranges, 2, diff))
+    barwidth <- (1 / 64) * diff(xranges)
+    barpos <- data.frame(
+      left = xranges[2] + barwidth, right = xranges[2] + barwidth * 2,
+      top = barmid + barlength / 2, bottom = barmid - barlength / 2,
+      parts = factor(colnames(yranges), levels = cn),
+      datetime = xranges[2], y = barmid
+    )
+    p <- p + ggplot2::geom_rect(ggplot2::aes_(xmin = ~left, xmax = ~right, ymax = ~top, ymin = ~bottom), data = barpos, fill = "gray75", colour = "black", size = 1 / 3)
+  }
+
+  # Add axis labels
+  p <- p + ggAddExtras(xlab = "Time", ylab = "")
+
+  # Make x axis contain only whole numbers (e.g., years)
+  p <- p + ggplot2::scale_x_continuous(breaks = unique(round(pretty(data$datetime))))
+
+  return(p)
 }
 
 #' @rdname autoplot.ts
 #' @export
-autolayer.mts <- function(object, colour=TRUE, series=NULL, ...) {
+autolayer.mts <- function(object, colour = TRUE, series = NULL, ...) {
   if (!requireNamespace("ggplot2", quietly = TRUE)) {
     stop("ggplot2 is needed for this function to work. Install it via install.packages(\"ggplot2\")", call. = FALSE)
   }
@@ -1679,7 +1690,7 @@ autolayer.mts <- function(object, colour=TRUE, series=NULL, ...) {
     cl$object <- quote(object[, i])
     if (length(series) != NCOL(object)) {
       if (colour) {
-        message("For a multivariate timeseries, specify a seriesname for each timeseries. Defaulting to column names.")
+        message("For a multivariate time series, specify a seriesname for each time series. Defaulting to column names.")
       }
       series <- colnames(object)
     }
@@ -1780,7 +1791,7 @@ autolayer.mforecast <- function(object, series = NULL, PI = TRUE, ...) {
 #' (for usage with ggplot2).
 #'
 #' @param object Object of class \dQuote{\code{ts}} or \dQuote{\code{mts}}.
-#' @param series Identifies the timeseries with a colour, which integrates well
+#' @param series Identifies the time series with a colour, which integrates well
 #' with the functionality of \link{geom_forecast}.
 #' @param facets If TRUE, multiple time series will be faceted (and unless
 #' specified, colour is set to FALSE). If FALSE, each series will be assigned a
