@@ -65,6 +65,9 @@ tslm <- function(formula, data, subset, lambda=NULL, biasadj=FALSE, ...) {
   ## Fix formula's environment for correct `...` scoping.
   attr(formula, ".Environment") <- environment()
 
+  ## Ensure response variable is taken from dataset (including transformations)
+  formula[[2]] <- as.symbol(deparse(formula[[2]]))
+
   if (sum(c(tsvar, fnvar)) > 0) {
     # Remove variables not needed in data (trend+season+functions)
     rmvar <- c(tsvar, fnvar)
@@ -143,8 +146,9 @@ tslm <- function(formula, data, subset, lambda=NULL, biasadj=FALSE, ...) {
     data <- data[subset, ] # model.frame(formula,as.data.frame(data[subsetTF,]))
   }
   if (!is.null(lambda)) {
-    data[, 1] <- BoxCox(data[, 1], lambda)
-    lambda <- attr(data[, 1], "lambda")
+    resp_var <- deparse(attr(mt, "variables")[[attr(mt, "response") + 1]])
+    data[, resp_var] <- BoxCox(data[, resp_var], lambda)
+    lambda <- attr(data[, resp_var], "lambda")
   }
   if (tsdat[2] == 0 && tsvar[2] != 0) {
     data$season <- factor(data$season) # fix for lost factor information, may not be needed?
@@ -467,7 +471,7 @@ forecast.lm <- function(object, newdata, h=10, level=c(80, 95), fan=FALSE, lambd
   }
 
   if (!is.null(lambda)) {
-    fcast$x <- InvBoxCox(fcast$x, lambda)
+    #fcast$x <- InvBoxCox(fcast$x, lambda)
     fcast$mean <- InvBoxCox(fcast$mean, lambda, biasadj, fcast)
     fcast$lower <- InvBoxCox(fcast$lower, lambda)
     fcast$upper <- InvBoxCox(fcast$upper, lambda)
@@ -476,12 +480,23 @@ forecast.lm <- function(object, newdata, h=10, level=c(80, 95), fan=FALSE, lambd
   return(structure(fcast, class = "forecast"))
 }
 
+#' @export
+summary.tslm <- function(object, ...) {
+  # Remove NA from object structure as summary.lm() expects (#836)
+  object$residuals <- na.omit(as.numeric(object$residuals))
+  object$fitted.values <- na.omit(as.numeric(object$fitted.values))
+  if(!is.null(object$lambda)) {
+    object$fitted.values <- BoxCox(object$fitted.values, object$lambda)
+  }
+  NextMethod()
+}
+
 # Compute cross-validation and information criteria from a linear model
 
 
 #' Cross-validation statistic
 #'
-#' Computes the leave-one-out cross-validation statistic (also known as PRESS
+#' Computes the leave-one-out cross-validation statistic (the mean of PRESS
 #' -- prediction residual sum of squares), AIC, corrected AIC, BIC and adjusted
 #' R^2 values for a linear model.
 #'
