@@ -11,7 +11,7 @@
 #' @param iterate Number of iterations to use to refine the seasonal component.
 #' @param s.window Seasonal windows to be used in the  decompositions. If scalar,
 #' the same value is used for all seasonal components. Otherwise, it should be a vector
-#' of the same length as the number of seasonal components.
+#' of the same length as the number of seasonal components (or longer).
 #' @param ... Other arguments are passed to \code{\link[stats]{stl}}.
 #' @inheritParams forecast
 #'
@@ -21,7 +21,7 @@
 #' mstl(taylor) %>% autoplot()
 #' mstl(AirPassengers, lambda = "auto") %>% autoplot()
 #' @export
-mstl <- function(x, lambda = NULL, iterate = 2, s.window = 13, ...) {
+mstl <- function(x, lambda = NULL, iterate = 2, s.window = 7+4*seq(6), ...) {
   # What is x?
   origx <- x
   n <- length(x)
@@ -30,7 +30,7 @@ mstl <- function(x, lambda = NULL, iterate = 2, s.window = 13, ...) {
     if (any(msts >= n / 2)) {
       warning("Dropping seasonal components with fewer than two full periods.")
       msts <- msts[msts < n / 2]
-      x <- forecast::msts(x, seasonal.periods = msts)
+      x <- msts(x, seasonal.periods = msts)
     }
     msts <- sort(msts, decreasing = FALSE)
   }
@@ -56,7 +56,7 @@ mstl <- function(x, lambda = NULL, iterate = 2, s.window = 13, ...) {
 
   # Transform if necessary
   if (!is.null(lambda)) {
-    x <- forecast::BoxCox(x, lambda = lambda)
+    x <- BoxCox(x, lambda = lambda)
     lambda <- attr(x, "lambda")
   }
   tt <- seq_len(n)
@@ -96,28 +96,23 @@ mstl <- function(x, lambda = NULL, iterate = 2, s.window = 13, ...) {
   remainder <- deseas - trend
 
   # Package into matrix
-  output <- cbind(origx, trend)
+  output <- cbind(c(origx), c(trend))
   if (!is.null(msts)) {
     for (i in seq_along(msts)) {
-      output <- cbind(output, seas[[i]])
+      output <- cbind(output, c(seas[[i]]))
     }
   }
-  output <- cbind(output, remainder)
+  output <- cbind(output, c(remainder))
+  colnames(output) <- paste0("V",seq(NCOL(output)))
   colnames(output)[1L:2L] <- c("Data", "Trend")
   if (!is.null(msts)) {
     colnames(output)[2L + seq_along(msts)] <- paste0("Seasonal", round(msts, 2))
   }
   colnames(output)[NCOL(output)] <- "Remainder"
 
-  if (length(msts) > 1) {
-    attr(output, "seasonal.periods") <- msts
-    return(structure(output,
-      seasonal.periods = msts,
-      class = c("mstl", "mts", "msts", "ts")
-    ))
-  }
-
-  return(structure(output, class = c("mstl", "mts", "ts")))
+  output <- copy_msts(origx, output)
+  class(output) <- c("mstl", class(output))
+  return(output)
 }
 
 #' @rdname autoplot.seas
@@ -287,16 +282,14 @@ forecast.stl <- function(object, method = c("ets", "arima", "naive", "rwdrift"),
   }
 
   if ("mstl" %in% class(object)) {
-    seasonal.periods <- attr(object, "seasonal.periods")
-    if (is.null(seasonal.periods)) {
-      seasonal.periods <- frequency(object)
-    }
-    seascomp <- matrix(0, ncol = length(seasonal.periods), nrow = h)
-    for (i in seq_along(seasonal.periods))
-    {
-      mp <- round(seasonal.periods[i], 2)
-      n <- NROW(object)
-      colname <- paste0("Seasonal", mp)
+    seasoncolumns <- which(grepl("Season", colnames(object)))
+    nseasons <- length(seasoncolumns)
+    seascomp <- matrix(0, ncol = nseasons, nrow = h)
+    seasonal.periods <- as.numeric(sub("Seasonal","", colnames(object)[seasoncolumns]))
+    n <- NROW(object)
+    for (i in seq(nseasons)) {
+      mp <- seasonal.periods[i]
+      colname <- colnames(object)[seasoncolumns[i]]
       seascomp[, i] <- rep(object[n - rev(seq_len(mp)) + 1, colname], trunc(1 + (h - 1) / mp))[seq_len(h)]
     }
     lastseas <- rowSums(seascomp)
@@ -304,8 +297,7 @@ forecast.stl <- function(object, method = c("ets", "arima", "naive", "rwdrift"),
     seascols <- grep("Seasonal", colnames(object))
     allseas <- rowSumsTS(object[, seascols, drop = FALSE])
     series <- NULL
-  }
-  else if ("stl" %in% class(object)) {
+  } else if ("stl" %in% class(object)) {
     m <- frequency(object$time.series)
     n <- NROW(object$time.series)
     lastseas <- rep(seasonal(object)[n - (m:1) + 1], trunc(1 + (h - 1) / m))[1:h]
@@ -313,8 +305,7 @@ forecast.stl <- function(object, method = c("ets", "arima", "naive", "rwdrift"),
     tsp(xdata) <- tsp(object$time.series)
     allseas <- seasonal(object)
     series <- deparse(object$call$x)
-  }
-  else {
+  } else {
     stop("Unknown object class")
   }
 
@@ -324,15 +315,14 @@ forecast.stl <- function(object, method = c("ets", "arima", "naive", "rwdrift"),
   fcast <- forecastfunction(x.sa, h = h, level = level, ...)
 
   # Reseasonalize
-  fcast$mean <- fcast$mean + lastseas
-  fcast$upper <- fcast$upper + lastseas
-  fcast$lower <- fcast$lower + lastseas
+  fcast$mean <- future_msts(xdata, fcast$mean + lastseas)
+  fcast$upper <- future_msts(xdata, fcast$upper + lastseas)
+  fcast$lower <- future_msts(xdata, fcast$lower + lastseas)
   fcast$x <- xdata
   fcast$method <- paste("STL + ", fcast$method)
   fcast$series <- series
-  # fcast$seasonal <- ts(lastseas[1:m],frequency=m,start=tsp(object$time.series)[2]-1+1/m)
-  fcast$fitted <- fitted(fcast) + allseas
-  fcast$residuals <- fcast$x - fcast$fitted
+  fcast$fitted <- copy_msts(xdata, fitted(fcast) + allseas)
+  fcast$residuals <- copy_msts(xdata, fcast$x - fcast$fitted)
 
   if (!is.null(lambda)) {
     fcast$x <- InvBoxCox(fcast$x, lambda)
@@ -383,7 +373,7 @@ rowSumsTS <- function (mts) {
 # But it does not forecast. Instead, the result can be passed to forecast().
 #' @rdname forecast.stl
 #' @export
-stlm <- function(y, s.window = 13, robust = FALSE, method = c("ets", "arima"), modelfunction = NULL, model = NULL,
+stlm <- function(y, s.window = 7+4*seq(6), robust = FALSE, method = c("ets", "arima"), modelfunction = NULL, model = NULL,
                  etsmodel = "ZZN", lambda = NULL, biasadj = FALSE, xreg = NULL, allow.multiplicative.trend = FALSE, x = y, ...) {
   method <- match.arg(method)
 
@@ -516,7 +506,7 @@ forecast.stlm <- function(object, h = 2 * object$m, level = c(80, 95), fan = FAL
   # In-case forecast method uses different horizon length (such as using xregs)
   h <- NROW(fcast$mean)
   # Forecast seasonal series with seasonal naive
-  seasonal.periods <- attributes(object$stl)$seasonal.periods
+  seasonal.periods <- attributes(object$stl)$msts
   if (is.null(seasonal.periods)) {
     seasonal.periods <- frequency(object$stl)
   }
@@ -567,7 +557,7 @@ forecast.stlm <- function(object, h = 2 * object$m, level = c(80, 95), fan = FAL
 #'
 #' plot(stlf(AirPassengers, lambda = 0))
 #' @export
-stlf <- function(y, h = frequency(x) * 2, s.window = 13, t.window = NULL, robust = FALSE, lambda = NULL, biasadj = FALSE, x = y, ...) {
+stlf <- function(y, h = frequency(x) * 2, s.window = 7+4*seq(6), t.window = NULL, robust = FALSE, lambda = NULL, biasadj = FALSE, x = y, ...) {
   seriesname <- deparse(substitute(y))
 
   # Check univariate
